@@ -23,7 +23,7 @@ class Version(NamedTuple):
 
 appname: str = 'kitty'
 kitty_face = '🐱'
-version: Version = Version(0, 36, 4)
+version: Version = Version(0, 40, 1)
 str_version: str = '.'.join(map(str, version))
 _plat = sys.platform.lower()
 is_macos: bool = 'darwin' in _plat
@@ -247,7 +247,7 @@ def is_wayland(opts: Optional['Options'] = None) -> bool:
 supports_primary_selection = not is_macos
 
 
-def running_in_kitty(set_val: Optional[bool] = None) -> bool:
+def running_in_kitty(set_val: bool | None = None) -> bool:
     if set_val is not None:
         setattr(running_in_kitty, 'ans', set_val)
     return bool(getattr(running_in_kitty, 'ans', False))
@@ -330,3 +330,13 @@ def local_docs() -> str:
 def wrapped_kitten_names() -> frozenset[str]:
     import kitty.fast_data_types as f
     return frozenset(f.wrapped_kitten_names())
+
+
+_supports_window_occlusion = False
+
+
+def supports_window_occlusion(set: bool | None = None) -> bool:
+    global _supports_window_occlusion
+    if set is not None:
+        _supports_window_occlusion = set
+    return _supports_window_occlusion
